<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AccountItem</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="56"/>
        <source>Sync successful</source>
        <translation>Conexão bem-sucedida</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="57"/>
        <source>Network error</source>
        <translation>Erro de rede</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="58"/>
        <source>Server exception</source>
        <translation>Exceção do servidor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="59"/>
        <source>Storage full</source>
        <translation>Armazenamento cheio</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="225"/>
        <source>Local account</source>
        <translation>Conta local</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="227"/>
        <source>Event types</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="91"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="104"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="106"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="48"/>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="49"/>
        <source>Tuesday</source>
        <translation>Terça-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="50"/>
        <source>Wednesday</source>
        <translation>Quarta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="51"/>
        <source>Thursday</source>
        <translation>Quinta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="52"/>
        <source>Friday</source>
        <translation>Sexta-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="53"/>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="54"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="126"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="127"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="128"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="184"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsview.cpp" line="600"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsItem/cmonthschedulenumitem.cpp" line="96"/>
        <source>%1 more</source>
        <translation>%1 mais</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="65"/>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="223"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="112"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="289"/>
        <source>My Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="330"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="334"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="335"/>
        <source>Edit</source>
        <comment>button</comment>
        <translation>Editar</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cpushbutton.cpp" line="33"/>
        <source>New event type</source>
        <translation>Novo tipo de evento</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="612"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="908"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="71"/>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="269"/>
        <source>End time must be greater than start time</source>
        <translation>O tempo de término deve ser maior que o tempo de início</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="270"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="494"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="523"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1120"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1155"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1409"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1413"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="495"/>
        <source>At time of event</source>
        <translation>No momento do evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="496"/>
        <source>15 minutes before</source>
        <translation>15 minutos antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="497"/>
        <source>30 minutes before</source>
        <translation>30 minutos antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="498"/>
        <source>1 hour before</source>
        <translation>1 hora antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="499"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="525"/>
        <source>1 day before</source>
        <translation>1 dia antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="500"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="526"/>
        <source>2 days before</source>
        <translation>2 dias antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="501"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="527"/>
        <source>1 week before</source>
        <translation>1 semana antes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="524"/>
        <source>On start day (9:00 AM)</source>
        <translation>No dia de início (9:00 AM)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="571"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="778"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1176"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1177"/>
        <source>time(s)</source>
        <translation>vez(es)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="585"/>
        <source>Enter a name please</source>
        <translation>Digite um nome, por favor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="680"/>
        <source>The name can not only contain whitespaces</source>
        <translation>O nome não pode conter apenas espaços em branco</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="736"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="858"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="741"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="893"/>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="746"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="930"/>
        <source>All Day:</source>
        <translation>Dia Inteiro:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="751"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="996"/>
        <source>Starts:</source>
        <translation>Inicia em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="756"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1037"/>
        <source>Ends:</source>
        <translation>Termina em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="761"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1077"/>
        <source>Remind Me:</source>
        <translation>Lembre-me:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
        <source>Repeat:</source>
        <translation>Repetir:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="771"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
        <source>End Repeat:</source>
        <translation>Termina em:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="827"/>
        <source>Calendar account:</source>
        <translation>Conta de calendário:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="828"/>
        <source>Calendar account</source>
        <translation>Conta de calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="855"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="897"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="927"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="951"/>
        <source>Time:</source>
        <translation>Horário:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="952"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="959"/>
        <source>Solar</source>
        <translation>Solar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="960"/>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="993"/>
        <source>Starts</source>
        <translation>Inicia em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1034"/>
        <source>Ends</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1079"/>
        <source>Remind Me</source>
        <translation>Lembre-me</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1106"/>
        <source>Repeat</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1121"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1414"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1122"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1415"/>
        <source>Weekdays</source>
        <translation>Dias úteis</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1123"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1416"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1124"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1410"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1417"/>
        <source>Monthly</source>
        <translation>Mensalmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1125"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1411"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1418"/>
        <source>Yearly</source>
        <translation>Anualmente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
        <source>End Repeat</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1156"/>
        <source>After</source>
        <translation>Depois</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1157"/>
        <source>On</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1227"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1228"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="94"/>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Todas as ocorrências de um evento repetitivo devem ter o mesmo status durante o dia inteiro.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="95"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="112"/>
        <source>Do you want to change all occurrences?</source>
        <translation>Alterar todas as ocorrências?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="96"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="113"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="143"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="162"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="182"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="254"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="284"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="97"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="114"/>
        <source>Change All</source>
        <translation>Alterar Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="111"/>
        <source>You are changing the repeating rule of this event.</source>
        <translation>A regra de repetição deste evento será alterada.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="141"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="160"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="180"/>
        <source>You are deleting an event.</source>
        <translation>Um evento será excluído.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="142"/>
        <source>Are you sure you want to delete this event?</source>
        <translation>Excluir este evento?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="144"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="161"/>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Excluir todas as ocorrências deste evento; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="163"/>
        <source>Delete All</source>
        <translation>Excluir Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="164"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="184"/>
        <source>Delete Only This Event</source>
        <translation>Excluir Apenas Este Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="181"/>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Excluir este evento e todas as suas ocorrências futuras; ou apenas a ocorrência selecionada?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="183"/>
        <source>Delete All Future Events</source>
        <translation>Excluir Todos os Eventos Futuros</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="250"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="280"/>
        <source>You are changing a repeating event.</source>
        <translation>Um evento repetido será alterado.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="252"/>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Alterar apenas esta ocorrência do evento; ou todas as ocorrências?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="255"/>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="256"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="286"/>
        <source>Only This Event</source>
        <translation>Apenas Este Evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="282"/>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Alterar apenas esta ocorrência do evento; ou esta e todas as ocorrências futuras?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="285"/>
        <source>All Future Events</source>
        <translation>Todos os Eventos Futuros</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="397"/>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>Você selecionou um mês bissexto e será lembrado de acordo com as regras do calendário lunar.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="398"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="915"/>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="56"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="57"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="281"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="658"/>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleview.cpp" line="327"/>
        <source>ALL DAY</source>
        <translation>DIA INTEIRO</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="351"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="352"/>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="369"/>
        <source>24-hour clock</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="370"/>
        <source>12-hour clock</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
        <source>15 mins</source>
        <translation>15 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
        <source>30 mins</source>
        <translation>30 mins</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
        <source>1 hour</source>
        <translation>1 hora</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
        <source>24 hours</source>
        <translation>24 horas</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
        <source>Sync Now</source>
        <translation>Sincronizar Agora</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="561"/>
        <source>Last sync</source>
        <translation>Última sincronização</translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="86"/>
        <source>(%1 mins)</source>
        <translation>(%1 minutos)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="88"/>
        <source>(%1 hour)</source>
        <translation>(%1 hora)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="90"/>
        <source>(%1 hours)</source>
        <translation>(%1 horas)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="46"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="66"/>
        <source>W</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="74"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="108"/>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="109"/>
        <source>Search events and festivals</source>
        <translation>Procurar eventos e datas comemorativas</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Sun</source>
        <translation>Dom</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Mon</source>
        <translation>Seg</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Tue</source>
        <translation>Ter</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Wed</source>
        <translation>Qua</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Thu</source>
        <translation>Qui</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Fri</source>
        <translation>Sex</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="88"/>
        <source>Sat</source>
        <translation>Sáb</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="102"/>
        <source>Week</source>
        <translation>Semana</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="289"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="278"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="281"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="298"/>
        <source>No event</source>
        <translation>Nenhum evento</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="632"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="68"/>
        <source>Calendar</source>
        <translation>Calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="71"/>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>O Calendário é uma ferramenta que permite agendar e visualizar eventos.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="100"/>
        <source>Calendar</source>
        <translation>Calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="369"/>
        <source>Manage</source>
        <translation>Gerenciar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="376"/>
        <source>Privacy Policy</source>
        <translation>Política de Privacidade</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="941"/>
        <source>Syncing...</source>
        <translation>Sincronizando...</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="950"/>
        <source>Sync successful</source>
        <translation>Sincronização bem-sucedida</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="956"/>
        <source>Sync failed, please try later</source>
        <translation>A sincronização falhou, tente novamente mais tarde</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleRemindWidget.cpp" line="190"/>
        <source>All Day</source>
        <translation>Dia Inteiro</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="63"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="64"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="65"/>
        <source>New event</source>
        <translation>Novo evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="749"/>
        <source>New Event</source>
        <translation>Novo Evento</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="267"/>
        <source>You are deleting an event type.</source>
        <translation>Você está a eliminar um tipo de evento.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="268"/>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>Todos os eventos deste tipo serão eliminados e não poderão ser recuperados.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="269"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="270"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="103"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="134"/>
        <source>Manage calendar</source>
        <translation>Gerenciar calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="119"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="138"/>
        <source>Event types</source>
        <translation>Tipos de eventos</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="45"/>
        <source>Account settings</source>
        <translation>Configurações de conta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="49"/>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="60"/>
        <source>Select items to be synced</source>
        <translation>Selecionar itens para sincronizar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
        <source>Events</source>
        <translation>Eventos</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="70"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
        <source>General settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="81"/>
        <source>Sync interval</source>
        <translation>Intervalo de sincronização</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="111"/>
        <source>Calendar account</source>
        <translation>Conta de calendário</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="157"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="161"/>
        <source>First day of week</source>
        <translation>Primeiro dia da semana</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="169"/>
        <source>Time</source>
        <translation>Horário</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="628"/>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="356"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="109"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="286"/>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Hoje</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="36"/>
        <source>New event type</source>
        <translation>Novo tipo de evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="46"/>
        <source>Edit event type</source>
        <translation>Editar o tipo de evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="133"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="143"/>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="171"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="172"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="221"/>
        <source>The name can not only contain whitespaces</source>
        <translation>O nome não pode ser apenas espaços em branco</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="281"/>
        <source>Enter a name please</source>
        <translation>Digite um nome por favor</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="31"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="32"/>
        <source>Delete event</source>
        <translation>Excluir evento</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="35"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="36"/>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="37"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="40"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="41"/>
        <source>Select all</source>
        <translation>Selecionar Tudo</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="142"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="142"/>
        <source>M</source>
        <translation>M</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/timejumpdialog.cpp" line="45"/>
        <source>Go</source>
        <comment>button</comment>
        <translation>Ir</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="63"/>
        <source>Sign In</source>
        <comment>button</comment>
        <translation>Entrar</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="64"/>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="941"/>
        <source>Y</source>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="203"/>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="354"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="107"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="244"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="69"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="284"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="278"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="626"/>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Hoje</translation>
    </message>
</context>
</TS>